@@ -5,28 +5,40 @@ case fact('osfamily')
     username = 'root'
     groupname = 'system'
     scriptname = 'concatfragments.rb'
-    vardir = default['puppetvardir']
+    vardir = default.puppet['vardir']
+    if vardir.nil? or vardir == ''
+      vardir = '/opt/puppetlabs/puppet/cache'
+    end
   when 'Darwin'
     username = 'root'
     groupname = 'wheel'
     scriptname = 'concatfragments.rb'
-    vardir = default['puppetvardir']
+    vardir = default.puppet['vardir']
+    if vardir.nil? or vardir == ''
+      vardir = '/opt/puppetlabs/puppet/cache'
+    end
   when 'windows'
     username = 'Administrator'
     groupname = 'Administrators'
     scriptname = 'concatfragments.rb'
-    result = on default, "echo #{default['puppetvardir']}"
+    result = on default, "echo #{default.puppet['vardir']}"
     vardir = result.raw_output.chomp
   when 'Solaris'
     username = 'root'
     groupname = 'root'
     scriptname = 'concatfragments.rb'
-    vardir = default['puppetvardir']
+    vardir = default.puppet['vardir']
+    if vardir.nil? or vardir == ''
+      vardir = '/opt/puppetlabs/puppet/cache'
+    end
   else
     username = 'root'
     groupname = 'root'
     scriptname = 'concatfragments.rb'
-    vardir = default['puppetvardir']
+    vardir = default.puppet['vardir']
+    if vardir.nil? or vardir == ''
+      vardir = '/opt/puppetlabs/puppet/cache'
+    end
 end
 
 describe 'basic concat test' do
@@ -149,5 +161,39 @@ describe 'basic concat test' do
         it { should_not be_file }
       end
     end
+    context 'works when set to present with path that has special characters' do
+      filename = fact('osfamily') == 'windows' ? 'file(1)' : 'file(1:2)'
+
+      before(:all) do
+        pp = <<-EOS
+        file { '#{basedir}':
+          ensure => directory,
+        }
+        EOS
+        apply_manifest(pp)
+      end
+      pp="
+        concat { '#{filename}':
+          ensure => present,
+          path   => '#{basedir}/#{filename}',
+          mode   => '0644',
+        }
+        concat::fragment { '1':
+          target  => '#{filename}',
+          content => '1',
+          order   => '01',
+        }
+      "
+
+      it_behaves_like 'successfully_applied', pp
+
+      describe file("#{basedir}/#{filename}") do
+        it { should be_file }
+        it("should be mode", :unless => (fact('osfamily') == 'AIX' or fact('osfamily') == 'windows')) {
+          should be_mode 644
+        }
+        its(:content) { should match '1' }
+      end
+    end
   end
 end
